@@ -30,15 +30,15 @@ class ActorState:
         args: Union[
             DataClassInstance, List[DataClassInstance], Dict[str, DataClassInstance]
         ],
-        version: Optional[Union[int, str]] = None,
+        version: Optional[Union[int, str, ActorVersion]] = None,
         dependencies: Optional[List[ActorState]] = None,
     ) -> ActorState:
         """Compute a unique cache id"""
         if version is None:
-            assert hasattr(CLS, "VERSION"), "Class must have a VERSION attribute"
+            assert hasattr(CLS, "VERSION"), f"Class {CLS} must have a VERSION attribute"
             version = getattr(CLS, "VERSION")
 
-        assert isinstance(
+        assert version is not None and isinstance(
             version, (int, str, ActorVersion)
         ), "Version must be a string, a number, or an ActorVersion"
 
